@@ -221,6 +221,10 @@ file. (Used with pgpmode=previous)
 =item * B<ignore> does not restrict the version of the secondary
 tarballs. (Maybe useful for MUT)
 
+=item * B<group> requires the downloading upstream tarball to be newer than
+the version obtained from F<debian/changelog>. Package version is the
+concatenation of all "group" upstream version.
+
 =back
 
 =item * I<script> is executed at the end of B<uscan> execution with appropriate
@@ -314,12 +318,11 @@ Set the name of the secondary source tarball as I<<
 
 Set the compression I<method> when the tarball is repacked (persistent).
 
-Available I<method> values are B<xz>, B<gzip> (alias B<gz>), B<bzip2> (alias
-B<bz2>), and B<lzma>.  The default is B<gzip> for normal tarballs, and B<xz>
-for tarballs generated directly from a git repository.
-
-If the debian source format is not 1.0, setting this to B<xz> should
-help reduce the package size when the package is repacked.
+Available I<method> values are what mk-origtargz supports, so B<xz>, B<gzip>
+(alias B<gz>), B<bzip2> (alias B<bz2>), B<lzma>, B<default>. The default method
+is currently B<xz>.
+When uscan is launched in a debian source repository which format is "1.0" or
+undefined, the method switches to B<gzip>.
 
 Please note the repacking of the upstream tarballs by B<mk-origtargz> happens
 only if one of the following conditions is satisfied:
@@ -371,7 +374,7 @@ and packs the source tree with the specified tag via I<matching-pattern> into
 I<spkg-version>B<.tar.xz>.
 
 If the upstream publishes the released tarball via its web interface, please
-use it instead of using this mode.  This mode is the last resort method.
+use it instead of using this mode. This mode is the last resort method.
 
 For git mode, I<matching-pattern> specifies the full string matching pattern for
 tags instead of hrefs. If I<matching-pattern> is set to
@@ -382,7 +385,7 @@ L<WATCH FILE EXAMPLES>.
 
 If I<matching-pattern> is set to B<HEAD>, B<uscan> downloads source from the
 B<HEAD> of the git repository and the pertinent I<version> is automatically
-generated with the date and hush of the B<HEAD> of the git repository.
+generated with the date and hash of the B<HEAD> of the git repository.
 
 If I<matching-pattern> is set to B<heads/>I<branch>, B<uscan> downloads source
 from the named I<branch> of the git repository.
@@ -392,6 +395,11 @@ under the destination directory where the downloaded archive is generated.  This
 is normally erased after the B<uscan> execution.  This local repository is kept
 if B<--debug> option is used.
 
+If the current directory is a git repository and the searched repository is
+listed among the registered "remotes", then uscan will use it instead of cloning
+separately.  The only local change is that uscan will run a "fetch" command to
+refresh the repository.
+
 =back
 
 =item B<pretty=>I<rule>
@@ -427,6 +435,10 @@ Set the git clone operation I<mode>. The default is B<gitmode=shallow>.  For
 some dumb git server, you may need to manually set B<gitmode=full> to force full
 clone operation.
 
+If the current directory is a git repository and the searched repository is
+listed among the registered "remotes", then uscan will use it instead of cloning
+separately.
+
 =item B<pgpmode=>I<mode>
 
 Set the PGP/GPG signature verification I<mode>.
@@ -493,7 +505,8 @@ npmjs.com:
 
   version=4
   opts="searchmode=plain" \
-   https://registry.npmjs.org/aes-js https://registry.npmjs.com/aes-js/-/aes-js-(\d[\d\.]*)@ARCHIVE_EXT@
+   https://registry.npmjs.org/aes-js \
+   https://registry.npmjs.org/aes-js/-/aes-js-(\d[\d\.]*)@ARCHIVE_EXT@
 
 =back
 
@@ -1224,6 +1237,37 @@ watch file for this site without using the redirector.
 Sites which used to be hosted on the Google Code service should have migrated
 to elsewhere (github?).  Please look for the newer upstream site if available.
 
+=head2 npmjs.org (node modules)
+
+npmjs.org modules are published in JSON files. Here is a way to read them:
+
+  version=4
+  opts="searchmode=plain" \
+   https://registry.npmjs.org/aes-js \
+   https://registry.npmjs.org/aes-js/-/aes-js-(\d[\d\.]*)@ARCHIVE_EXT@
+
+=head2 grouped package
+
+Some node modules are split into multiple little upstream package. Here is
+a way to group them:
+
+  version=4
+  opts="searchmode=plain,pgpmode=none" \
+    https://registry.npmjs.org/mongodb \
+    https://registry.npmjs.org/mongodb/-/mongodb-(\d[\d\.]*)@ARCHIVE_EXT@ group
+  opts="searchmode=plain,pgpmode=none,component=bson" \
+    https://registry.npmjs.org/bson \
+    https://registry.npmjs.org/bson/-/bson-(\d[\d\.]*)@ARCHIVE_EXT@ group
+  opts="searchmode=plain,pgpmode=none,component=mongodb-core" \
+    https://registry.npmjs.org/mongodb-core \
+    https://registry.npmjs.org/mongodb-core/-/mongodb-core-(\d[\d\.]*)@ARCHIVE_EXT@ group
+  opts="searchmode=plain,pgpmode=none,component=requireoptional" \
+    https://registry.npmjs.org/require_optional \
+    https://registry.npmjs.org/require_optional/-/require_optional-(\d[\d\.]*)@ARCHIVE_EXT@ group
+
+Package version is then the concatenation of upstream versions separated by
+"+~".
+
 =head2 direct access to the git repository (tags)
 
 If the upstream only publishes its code via the git repository and its code has
@@ -1624,8 +1668,19 @@ variables are:
 
 =item B<USCAN_DOWNLOAD>
 
-If this is set to B<no>, then newer upstream files will not be downloaded; this
-is equivalent to the B<--no-download> options.
+Download or report only:
+
+=over
+
+=item B<no>: equivalent to B<--no-download>, newer upstream files will
+not be downloaded.
+
+=item B<yes>: equivalent to B<--download>, newer upstream files will
+be downloaded. This is the default behavior.
+
+See also B<--force-download> and B<--overwrite-download>.
+
+=back
 
 =item B<USCAN_SAFE>
 
@@ -1922,6 +1977,14 @@ BEGIN {
 
 my $config = Devscripts::Uscan::Config->new->parse;
 
+uscan_verbose "$progname (version $uscan_version) See $progname(1) for help";
+if ($dehs) {
+    uscan_verbose "The --dehs option enabled.\n"
+      . "        STDOUT = XML output for use by other programs\n"
+      . "        STDERR = plain text output for human\n"
+      . "        Use the redirection of STDOUT to a file to get the clean XML data";
+}
+
 # Did we find any new upstream versions on our wanderings?
 our $found = 0;
 
